pymodaq_plugins_horiba (Horiba Spectrometers)
#############################################

.. image:: https://img.shields.io/pypi/v/pymodaq_plugins_horiba.svg
   :target: https://pypi.org/project/pymodaq_plugins_horiba/
   :alt: Latest Version

.. image:: https://readthedocs.org/projects/pymodaq/badge/?version=latest
   :target: https://pymodaq.readthedocs.io/en/stable/?badge=latest
   :alt: Documentation Status

.. image:: https://github.com/PyMoDAQ/pymodaq_plugins_horiba/workflows/Upload%20Python%20Package/badge.svg
    :target: https://github.com/PyMoDAQ/pymodaq_plugins_horiba

PyMoDAQ plugin for Horiba Instruments (Lapspec6TCP to communicate with labspec
software using the AFM TCP/IP protocol


Authors
=======

* Sebastien J. Weber

Instruments
===========
Below is the list of instruments included in this plugin


Viewer1D
++++++++

* **Labspec6TCP**: Control of Labspec6 settings and acquisition using TCP/IP communication
